from zcfd.solvers.utils.DGNodalLocations import *

# Zone: 12 SYM2
# Zone: 13 WALL
# Zone: 14 FF
# Zone: 15 SYM1

import zutil
import math

lt = 0.005
spacing = 0.5 * lt

lx = 0.15
ly = 0.075
lz = spacing
blend = 0.25 * ly

skip = -1

reynolds = 1.7e6
mach = 0.17
T = 288
p = 101325
R = 287.6
gamma = 1.4

rho = p / (R * T)
U = math.sqrt(gamma * R * T) * mach
d = 0.457

alpha = 4.0

parameters = {
    # units for dimensional quantities
    "units": "SI",
    # reference state
    "reference": "IC_1",
    "time marching": {
        "unsteady": {
            "total time": 0.05,
        },
        "multi level": True,
        "cfl": 0.05/3.0,
    },
    "equations": "DGCAA",
    "Nodal Locations": {
        "Line": line_gauss_lobatto,
        "Tetrahedron": tet_shunn_ham,
        "Tri": tri_shunn_ham,
    },
    "Sponge Layer Damping": {
        "Distance": 0.25,
        "Damping Factor": 2.0,
    },
    "DGCAA": {
        "order": 1,
        "Map CFD to CAA mesh": False,
        "RANS mesh name": "30p30n_coarse.h5",
        "RANS case name": "30p30n_steady.py",
        "frpm sources": True,
        "microphone output frequency": 10,
        "FRPM_1": {
            "map cfd to frpm mesh": True,
            "number of frpm mpi processes": 1,
            "FRPM Spacing": 0.0025,
            "FRPM Turbulence Integral Length Scale": 0.005,
            "FRPM Cart Num Mesh Cells": [int(0.15 / 0.0025), int(0.075 / 0.0025), 1],
            "FRPM March Frequency": -1,
            "FRPM Domain Translate": [-0.035, -0.085, 0.5],
            "FRPM Domain Rotate (Deg)": [0.0, 0.0, 30.0],
            "FRPM Blend Sources From Side": [ 0.01875, 5.0 * 0.01875, 0.01875,
                                              0.01875, 0.0, 0.0],
            "FRPM Mapped TKE Smoothing iterations": 5,
            "use constant integral length scale": False,
        },
    },
    "material": "air",
    "air": {
        "gamma": 1.4,
        "gas constant": 287.0,
        "Sutherlands const": 110.4,
        "Prandtl No": 0.72,
        "Turbulent Prandtl No": 0.9,
    },
    "IC_1": {
        "temperature": T,
        "pressure": p,
        "V": {
            "vector": zutil.vector_from_angle(0.0, alpha, U),
        },
        "Reynolds No": reynolds,
        "Reference Length": d,
        "turbulence intensity": 0.01,
        "eddy viscosity ratio": 0.1,
        "ambient turbulence intensity": 1e-20,
        "ambient eddy viscosity ratio": 1e-20,
    },
    "BC_1": {
        "zone": [5, 6, 7],
        "type": "wall",
        "kind": "slip",
    },
    "BC_2": {
        "zone": [1,2,3,4],
        "type": "farfield",
        "condition": "IC_1",
        "kind": "pressure",
    },
    "report": {
        "frequency": 10,
        "monitor": {
            "MR_1": {
                "name": "probe1",
                "point": [-0.0347784, 0.02431, 0.5025],
                "variables": ["var_1"],
            },
            "MR_2": {
                "name": "probe2",
                "point": [0.0, -1.5 * 0.457, 0.5025],
                "variables": ["var_1"],
            },
        },
    },
    "write output": {
        "frequency": 10000,
        "format": "vtk",
        "surface variables": [],
        "volume variables": [
            "sponge",
            "src_x",
            "src_y",
            "src_z",
            "mean_velocity",
            "mean_density",
            "mean_sound",
            "var_1",
            "var_2",
            "var_3",
            "var_4",
        ],
    },
}
